#
# spec file for package apache2-mod_auth_openidc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define apxs %{_bindir}/apxs2
%define apache_libexecdir %(%{apxs} -q LIBEXECDIR)
Name:           apache2-mod_auth_openidc
Version:        2.3.8
Release:        150600.16.11.1
Summary:        Apache2.x module for an OpenID Connect enabled Identity Provider
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://github.com/zmartzone/mod_auth_openidc/
Source:         https://github.com/zmartzone/mod_auth_openidc/archive/v%{version}.tar.gz
Patch0:         apache2-mod_auth_openidc-2.3.8-CVE-2019-14857.patch
Patch1:         apache2-mod_auth_openidc-2.3.8-CVE-2019-20479.patch
Patch2:         fix-CVE-2021-32785.patch
Patch3:         fix-CVE-2021-32786.patch
Patch4:         fix-CVE-2021-32791.patch
Patch5:         fix-CVE-2021-32792-1.patch
Patch6:         fix-CVE-2021-32792-2.patch
Patch7:         fix-CVE-2021-39191.patch
# PATCH-FIX-UPSTREAM danilo.spinella@suse.com bsc#1206441
# Open Redirect in oidc_validate_redirect_url() using tab character
Patch8:         fix-CVE-2022-23527-0.patch
Patch9:         fix-CVE-2022-23527-1.patch
Patch10:        fix-CVE-2022-23527-2.patch
Patch11:        fix-CVE-2022-23527-3.patch
# PATCH-FIX-UPSTREAm danilo.spinella@suse.com
# https://github.com/zmartzone/mod_auth_openidc/commit/8ea550f34ce51d8d41ba47843739c964407fa0ad#diff-d96ed9829fce9f8bbd63bf1be03700bf5a8f8b5614ac1b68015edbf456ecf303R3432-R3439
Patch12:        harden-refresh-token-request.patch
# PATCH-FIX-UPSTREAM danilo.spinella@suse.com bsc#1210073 CVE-2023-28625
Patch13:        fix-CVE-2023-28625.patch
# PATCH-FIX-UPSTREAM danilo.spinella@suse.com bsc#1219911 CVE-2024-24814
# DoS when `OIDCSessionType client-cookie` is set and a crafted Cookie header is supplied
Patch14:        fix-CVE-2024-24814.patch
# CVE-2025-31492 [bsc#1240893], OIDCProviderAuthRequestMethod POSTs can leak protected data
Patch15:        apache2-mod_auth_openidc-CVE-2025-31492.patch
# CVE-2025-3891 [bsc#1242015], denial of service via an empty POST request when OIDCPreservePost is enabled
Patch16:        apache2-mod_auth_openidc-CVE-2025-3891.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
%if 0%{?suse_version} >= 1550
BuildRequires:  hiredis-devel
%endif
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cjose) >= 0.4.1
BuildRequires:  pkgconfig(jansson) >= 2.0
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(openssl) >= 1.0.1
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}

%description
This module enables an Apache 2.x web server to operate as an OpenID Connect Relying Party and/or OAuth 2.0 Resource Server.

%prep
%autosetup -p1 -n mod_auth_openidc-%{version}

%build
./autogen.sh
%configure \
%if 0%{?is_opensuse} > 0
  %{?_with_hiredis}    \
%else
  %{?_without_hiredis} \
%endif

make %{?_smp_mflags}

%install
install -D -m0755 src/.libs/mod_auth_openidc.so %{buildroot}%{apache_libexecdir}/mod_auth_openidc.so

%check
make -j1 test

%files
%dir %{apache_libexecdir}
%{apache_libexecdir}/mod_auth_openidc.so

%changelog
* Tue Jun  3 2025 pgajdos@suse.com
- security update
- added patches
  CVE-2025-3891 [bsc#1242015], denial of service via an empty POST request when OIDCPreservePost is enabled
  + apache2-mod_auth_openidc-CVE-2025-3891.patch
* Fri Apr 11 2025 pgajdos@suse.com
- security update
- added patches
  fix CVE-2025-31492 [bsc#1240893], OIDCProviderAuthRequestMethod POSTs can leak protected data
  + apache2-mod_auth_openidc-CVE-2025-31492.patch
- enable the testsuite
* Wed Jul  3 2024 danilo.spinella@suse.com
- Fix apxs2 binary location, which made the library file be installed in root folder,
  bsc#1227261
* Thu Jun 27 2024 danilo.spinella@suse.com
- Fix CVE-2024-24814, DoS when `OIDCSessionType client-cookie` is set
  and a crafted Cookie header is supplied, bsc#1219911
  * fix-CVE-2024-24814.patch
* Tue Apr  4 2023 danilo.spinella@suse.com
- Fix CVE-2023-28625, NULL pointer dereference when OIDCStripCookies is
  set and a crafted Cookie header is supplied, bsc#1210073
  * fix-CVE-2023-28625.patch
* Fri Dec 23 2022 danilo.spinella@suse.com
- Fix CVE-2022-23527, Open Redirect in oidc_validate_redirect_url() using tab character
  (CVE-2022-23527, bsc#1206441)
  * fix-CVE-2022-23527-0.patch
  * fix-CVE-2022-23527-1.patch
  * fix-CVE-2022-23527-3.patch
  * fix-CVE-2022-23527-2.patch
- Harden oidc_handle_refresh_token_request function
  * harden-refresh-token-request.patch
- Fixes bsc#1199868, mod_auth_openidc not loading
* Wed Apr 13 2022 danilo.spinella@suse.com
- Fix CVE-2021-39191 open redirect issue in target_link_uri parameter
  (CVE-2021-39191, bsc#1190223)
  * fix-CVE-2021-39191.patch
* Wed Jul 28 2021 danilo.spinella@suse.com
- Fix CVE-2021-32791 Hardcoded static IV and AAD with a reused key in AES GCM encryption
  (CVE-2021-32791, bsc#1188849)
  * fix-CVE-2021-32791.patch
- Fix CVE-2021-32792 XSS when using OIDCPreservePost On
  (CVE-2021-32792, bsc#1188848)
  * fix-CVE-2021-32792-1.patch
  * fix-CVE-2021-32792-2.patch
* Fri Jul 23 2021 danilo.spinella@suse.com
- Fix CVE-2021-32785 format string bug via hiredis
  (CVE-2021-32785, bsc#1188638)
  * fix-CVE-2021-32785.patch
- Fix CVE-2021-32786 open redirect in logout functionality
  (CVE-2021-32786, bsc#1188639)
  * fix-CVE-2021-32786.patch
- Refresh apache2-mod_auth_openidc-2.3.8-CVE-2019-20479.patch
* Thu Apr  1 2021 pgajdos@suse.com
- require hiredis only for newer distros than SLE-15 [jsc#SLE-11726]
* Wed Mar  4 2020 kstreitova@suse.com
- add apache2-mod_auth_openidc-2.3.8-CVE-2019-20479.patch to fix
  open redirect issue that exists in URLs with a slash and
  backslash at the beginning [bsc#1164459], [CVE-2019-20479]
* Wed Oct 30 2019 kstreitova@suse.com
- add apache2-mod_auth_openidc-2.3.8-CVE-2019-14857.patch to fix
  open redirect issue that exists in URLs with trailing slashes
  [bsc#1153666], [CVE-2019-14857]
* Fri Nov  9 2018 kstreitova@suse.com
- submission to SLE15SP1 because of fate#324447
- build with hiredis only for openSUSE where hiredis is available
- add a version for jansson BuildRequires
* Tue Oct 30 2018 kstreitova@suse.com
- update to 2.3.8
- changes in 2.3.8
  * fix return result FALSE when JWT payload parsing fails
  * add LGTM code quality badges
  * fix 3 LGTM alerts
  * improve auto-detection of XMLHttpRequests via Accept header
  * initialize test_proto_authorization_request properly
  * add sanity check on provider->auth_request_method
  * allow usage with LibreSSL
  * don't return content with 503 since it will turn the HTTP
    status code into a 200
  * add option to set an upper limit to the number of concurrent
    state cookies via OIDCStateMaxNumberOfCookies
  * make the default maximum number of parallel state cookies
    7 instead of unlimited
  * fix using access token as endpoint auth method in
    introspection calls
  * fix reading access_token form POST parameters when combined
    with `AuthType auth-openidc`
- changes in 2.3.7
  * abort when string length for remote user name substitution
    is larger than 255 characters
  * fix Redis concurrency issue when used with multiple vhosts
  * add support for authorization server metadata with
    OIDCOAuthServerMetadataURL as in RFC 8414
  * refactor session object creation
  * clear session cookie and contents if cache corruption is detected
  * use apr_pstrdup when setting r->user
  * reserve 255 characters in remote username substition instead of 50
- changes in 2.3.6
  * add check to detect session cache corruption for server-based
    caches and cached static metadata
  * avoid using pipelining for Redis
  * send Basic header in OAuth www-authenticate response if that's
    the only accepted method; thanks @puiterwijk
  * refactor Redis cache backend to solve issues on AUTH errors:
    a) memory leak and b) redisGetReply lagging behind
  * adjust copyright year/org
  * fix buffer overflow in shm cache key set strcpy
  * turn missing session_state from warning into a debug statement
  * fix missing "return" on error return from the OP
  * explicitly set encryption kid so we're compatible with
    cjose >= 0.6.0
- changes in 2.3.5
  * fix encoding of preserved POST data
  * avoid buffer overflow in shm cache key construction
  * compile with with Libressl
* Fri Apr 27 2018 vcizek@suse.com
- update to 2.3.4
- requested in fate#323817
* Wed Dec 13 2017 christof.hanke@mpcdf.mpg.de
- initial packaging
